import { readFile } from 'fs';
import * as vscode from 'vscode';
import { getNonce } from './getNonce';
import { fileFolderHelperExe } from './constants';
import { ExecException, exec } from 'child_process';
import { ReceivedMessage } from './ReceivedMessage';

async function postRelativePath(extensionUri: vscode.Uri, webviewPanel: vscode.WebviewPanel, receivedMessage: ReceivedMessage) {
  if (vscode.workspace.workspaceFolders === undefined) {
    vscode.window.showInformationMessage('Open workspace first!');
  }
  else {
    const workspaceFoldersZero = vscode.workspace.workspaceFolders[0].uri;
    const inputUri: vscode.Uri = vscode.Uri.joinPath(workspaceFoldersZero, '.vscode', 'input.json');
    readFile(inputUri.fsPath, (err, data) =>
      inputUriRead(extensionUri, webviewPanel, receivedMessage, workspaceFoldersZero, inputUri, err, data.toString('utf8')));
  }
}

function inputUriRead(extensionUri: vscode.Uri, webviewPanel: vscode.WebviewPanel, receivedMessage: ReceivedMessage, workspaceFoldersZero: vscode.Uri, inputUri: vscode.Uri, err: NodeJS.ErrnoException | null, data: string) {
  if (err) {
    vscode.window.showInformationMessage(`<${inputUri.fsPath}> doesn't exist! ${err.message}`);
  }
  else {
    const jsonObject: any = JSON.parse(data);
    if (!jsonObject.BaseAddresses || !jsonObject.Page || jsonObject.BaseAddresses.length === 0) {
      vscode.window.showInformationMessage(`<${inputUri.fsPath}> doesn't have valid json! ${data}`);
    }
    else {
      const relativePathUri: vscode.Uri = vscode.Uri.joinPath(workspaceFoldersZero, '.vscode', 'RelativePath.json');
      const fileFolderHelper: vscode.Uri = vscode.Uri.joinPath(extensionUri, 'net8.0', 'win-x64', 'publish', fileFolderHelperExe);
      const command: string = `${fileFolderHelper.fsPath} s X "${workspaceFoldersZero.fsPath}" Day-Helper-2025-05-19 "${inputUri.fsPath}"`;
      exec(command, (error, stdout, stderr) =>
        execCallback(webviewPanel, receivedMessage, jsonObject, relativePathUri, error, stdout, stderr));
    }
  }
}

function execCallback(webviewPanel: vscode.WebviewPanel, receivedMessage: ReceivedMessage, jsonObject: any, relativePathUri: vscode.Uri, error: ExecException | null, stdout: string, stderr: string) {
  if (error) {
    vscode.window.showInformationMessage(error.message);
    return;
  }
  if (stderr) {
    vscode.window.showInformationMessage(stderr);
    return;
  }
  console.log(`stdout: ${stdout}`);
  readFile(relativePathUri.fsPath, (err, data) =>
    relativePathUriRead(webviewPanel, receivedMessage, jsonObject, relativePathUri, err, data.toString('utf8')));
};

function relativePathUriRead(webviewPanel: vscode.WebviewPanel, receivedMessage: ReceivedMessage, jsonObject: any, relativePathUri: vscode.Uri, err: NodeJS.ErrnoException | null, data: string) {
  if (err) {
    vscode.window.showInformationMessage(`<${relativePathUri.fsPath}> doesn't exist! ${err.message}`);
  }
  else {
    // const jsonObject: any = JSON.parse(data);
    // const receivedMessage: ReceivedMessage = { command: 'File-Folder-Helper', subcommand: 'post', value: jsonObject, collection: [] };
    // receivedMessage.command = 'done';
    // webviewPanel.webview.postMessage(receivedMessage);
    const message = { command: receivedMessage.subcommand, from: receivedMessage.command + '-' + receivedMessage.subcommand, input: jsonObject, relativePath: data };
    webviewPanel.webview.postMessage(message);
  }
}

export class WebviewPanelFileSync {

  public static _title: string;
  public static readonly viewType = 'web-view-panel';
  public static currentPanel: WebviewPanelFileSync | undefined;

  private _disposables: vscode.Disposable[] = [];

  public static createOrShow(extensionContext: vscode.ExtensionContext, title: string) {
    this._title = title;

    const column = vscode.window.activeTextEditor
      ? vscode.window.activeTextEditor.viewColumn
      : undefined;

    if (WebviewPanelFileSync.currentPanel) {
      WebviewPanelFileSync.currentPanel._panel.reveal(column);
      WebviewPanelFileSync.currentPanel._update(title);
      return;
    }

    const panel = vscode.window.createWebviewPanel(
      WebviewPanelFileSync.viewType,
      title,
      column || vscode.ViewColumn.One,
      {
        enableScripts: true,
        enableFindWidget: true,
        localResourceRoots: [
          vscode.Uri.joinPath(extensionContext.extensionUri, 'dist'),
          vscode.Uri.joinPath(extensionContext.extensionUri, 'media'),
        ],
      }
    );

    WebviewPanelFileSync.currentPanel = new WebviewPanelFileSync(extensionContext, panel, title);
  }

  public static kill() {
    WebviewPanelFileSync.currentPanel?.dispose();
    WebviewPanelFileSync.currentPanel = undefined;
  }

  public static revive(panel: vscode.WebviewPanel, extensionContext: vscode.ExtensionContext) {
    WebviewPanelFileSync.currentPanel = new WebviewPanelFileSync(extensionContext, panel, this._title);
  }

  public dispose() {
    WebviewPanelFileSync.currentPanel = undefined;
    this._panel.dispose();
    while (this._disposables.length) {
      const x = this._disposables.pop();
      if (x) {
        x.dispose();
      }
    }
  }

  private constructor(private readonly _extensionContext: vscode.ExtensionContext, private readonly _panel: vscode.WebviewPanel, title: string) {
    this._update(title);
    this._panel.onDidDispose(() => this.dispose(), null, this._disposables);
  }

  private async _update(title: string) {
    const webview = this._panel.webview;
    this._panel.webview.html = this._getHtmlForWebview(title, webview);
    webview.onDidReceiveMessage(
      (receivedMessage: ReceivedMessage) => {
        WebviewPanelFileSync.onDidReceiveMessage(
          this._extensionContext.extensionUri,
          this._panel,
          receivedMessage
        );
      },
      null,
      this._disposables
    );
  }

  private static onDidReceiveMessage(extensionUri: vscode.Uri, webviewPanel: vscode.WebviewPanel, receivedMessage: ReceivedMessage) {
    switch (receivedMessage.command) {
      case 'alert':
        vscode.window.showErrorMessage(receivedMessage.value);
        return;
      case fileFolderHelperExe:
        if (receivedMessage.subcommand === 'post') {
          postRelativePath(extensionUri, webviewPanel, receivedMessage);
        }
        return;
      default:
        vscode.window.showErrorMessage(receivedMessage.value);
        break;
    }
  }

  private _getHtmlForWebview(title: string, webview: vscode.Webview) {
    // Use a nonce to only allow a specific script to be run.
    const nonce = getNonce();

    if (title === 'HTML') {
      return `<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Infineon - ${title}</title>
</head>
<body>
  ${title}
</body>
</html>`;
    }
    else {
      const styleCostOfDelayUri = webview.asWebviewUri(vscode.Uri.joinPath(this._extensionContext.extensionUri, "media", "cod.css"));
      const scriptEmbedRollup = webview.asWebviewUri(vscode.Uri.joinPath(this._extensionContext.extensionUri, "dist", "embed-rollup.js"));
      const scriptJQueryUri = webview.asWebviewUri(vscode.Uri.joinPath(this._extensionContext.extensionUri, "media", "jquery-1.6.4.min.js"));
      const styleBootstrapUri = webview.asWebviewUri(vscode.Uri.joinPath(this._extensionContext.extensionUri, "media", "bootstrap.min.css"));

      return `<!DOCTYPE html>
<html lang="en">

<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Infineon - ${title}</title>
    <link href="${styleBootstrapUri}" rel="stylesheet" />
    <link href="${styleCostOfDelayUri}" rel="stylesheet" />
    <script nonce="${nonce}" src="${scriptJQueryUri}" type="text/javascript"></script>
    <script nonce="${nonce}" type="text/javascript">
      const acquiredVsCodeApi = acquireVsCodeApi();
      const _webviewUsername = '${process.env.USERNAME}';
      const _webviewMachineId = '${vscode.env.machineId}';
    </script>
</head>

<body>
    <div class="navbar navbar-fixed-top">
        <div class="container-fluid">
            <div class="navbar-header">
                <button type="button" class="navbar-toggle" data-toggle="collapse" data-target=".navbar-collapse">
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                    <span class="icon-bar"></span>
                </button>
                <div class="navbar-brand">
                    <span id="siteHeader">&nbsp;</span> -
                    <span id="th-span">&nbsp;</span>
                    <button id="toggle" onclick="getRelativePathAndPost()">Toggle</button>
                </div>
            </div>
            <div class="navbar-collapse collapse">
                <ul class="nav navbar-nav">
                </ul>
                <p class="navbar-text navbar-right">
                    &nbsp;
                </p>
            </div>
        </div>
    </div>
    <div class="container-fluid body-content" style="margin-top: 40px; margin-left: 15px;">
        <script nonce="${nonce}" src="${scriptEmbedRollup}" type="text/javascript"></script>

        <div id="HeaderGridDiv">
            <table id="HeaderGrid" border="1"></table>
        </div>

        <br />&nbsp;

        <textarea id="AllTextarea" rows="20" cols="147"></textarea>
    </div>
</body>
</html>`;
    }
  }
}
