import * as vscode from 'vscode';
import * as editorCalc from 'editor-calc';

export class CalcProvider implements vscode.CompletionItemProvider {
  public enableActive: boolean;

  private decorationType: vscode.TextEditorDecorationType;

  constructor(
    public config: vscode.WorkspaceConfiguration,
    private onError: (error: unknown) => any,
  ) {
    this.enableActive = false;
    this.decorationType = vscode.window.createTextEditorDecorationType({
      dark: {
        border: '1px dashed gray',
      },
      light: {
        border: '1px dashed black',
      },
    });
  }

  public async highlight(range: vscode.Range) {
    const editor = vscode.window.activeTextEditor;
    if (editor) {
      editor.setDecorations(this.decorationType, [range]);
    }
  }

  public async clearHighlight() {
    const editor = vscode.window.activeTextEditor;
    if (editor) {
      editor.setDecorations(this.decorationType, []);
    }
  }

  public calculateLine(
    position: vscode.Position,
    exprLine: string,
  ): {
    skip: number;
    result: string;
    insertText: string;
    expressionRange: vscode.Range;
    expressionWithEqualSignRange: vscode.Range;
    expressionEndRange: vscode.Range;
  } | null {
    let skip, result;
    try {
      ({ skip, result } = editorCalc.calculate(exprLine));
    } catch (error) {
      this.onError(error);
      return null;
    }
    const formulaRaw = exprLine.slice(skip);
    const leftMatches = formulaRaw.match(/^\s+/);
    const leftEmpty = leftMatches ? leftMatches[0].length : 0;
    const rightMatches = formulaRaw.match(/[\s=]+$/);
    const rightEmpty = rightMatches ? rightMatches[0].length : 0;

    const insertText = exprLine.endsWith(' =') ? ` ${result}` : result;

    return {
      skip,
      result,
      insertText,
      expressionRange: new vscode.Range(
        position.line,
        skip + leftEmpty,
        position.line,
        position.character - rightEmpty,
      ),
      expressionWithEqualSignRange: new vscode.Range(
        position.line,
        skip + leftEmpty,
        position.line,
        position.character,
      ),
      expressionEndRange: new vscode.Range(
        position.line,
        position.character,
        position.line,
        position.character,
      ),
    };
  }

  private getCompletionResultsFromExtraCursors(document: vscode.TextDocument): {
    additionalReplacements: vscode.Range[];
    additionalTextInserts: string[];
    additionalResults: string[];
  } {
    const additionalReplacements = [];
    const additionalTextInserts = [];
    const additionalResults = [];

    const editor = vscode.window.activeTextEditor;
    if (editor) {
      for (const selection of editor.selections.slice(1)) {
        const position = selection.active;
        const exprLine = document.getText(
          new vscode.Range(new vscode.Position(position.line, 0), position),
        );
        const lineCalcResult = this.calculateLine(position, exprLine);
        if (lineCalcResult == null) {
          continue;
        }
        const { expressionWithEqualSignRange, insertText, result } =
          lineCalcResult;
        additionalReplacements.push(expressionWithEqualSignRange);
        additionalTextInserts.push(insertText);
        additionalResults.push(result);
      }
    }

    return { additionalReplacements, additionalTextInserts, additionalResults };
  }

  public async provideCompletionItems(
    document: vscode.TextDocument,
    position: vscode.Position,
    _token: vscode.CancellationToken,
    _context: vscode.CompletionContext,
  ): Promise<vscode.CompletionItem[]> {
    const exprLine = document.getText(
      new vscode.Range(new vscode.Position(position.line, 0), position),
    );
    if (!this.enableActive && !exprLine.trimRight().endsWith('=')) {
      return [];
    }
    const lineCalcResult = this.calculateLine(position, exprLine);
    if (lineCalcResult == null) {
      return [];
    }
    const {
      skip,
      result,
      expressionRange,
      expressionWithEqualSignRange,
      expressionEndRange,
      insertText,
    } = lineCalcResult;

    this.clearHighlight().catch(this.onError);

    this.highlight(expressionRange).catch(this.onError);

    const { additionalReplacements, additionalTextInserts, additionalResults } =
      this.getCompletionResultsFromExtraCursors(document);
    const documentationPostfix =
      additionalResults.length > 0 ? ' (multiple)' : '';

    return [
      {
        label: result,
        kind: vscode.CompletionItemKind.Constant,
        detail: `calc append${documentationPostfix}`,
        documentation: `\`${exprLine
          .slice(skip)
          .trimStart()}${insertText}\`${documentationPostfix}`,
        range: expressionEndRange,
        additionalTextEdits: [
          vscode.TextEdit.insert(expressionWithEqualSignRange.end, insertText),
          ...additionalReplacements.map((replacementRange, i) =>
            vscode.TextEdit.insert(replacementRange.end, additionalTextInserts[i]),
          ),
        ],
        insertText: '', // text specified here will be inserted on every line
      },
      {
        label: result,
        kind: vscode.CompletionItemKind.Constant,
        detail: `calc replace${documentationPostfix}`,
        documentation: `\`${result}\`${documentationPostfix}`,
        additionalTextEdits: [
          vscode.TextEdit.replace(expressionWithEqualSignRange, result),
          ...additionalReplacements.map((replacementRange, i) =>
            vscode.TextEdit.replace(replacementRange, additionalResults[i]),
          ),
        ],
        insertText: '',
      },
    ];
  }

  async resolveCompletionItem(
    item: vscode.CompletionItem,
    _token: vscode.CancellationToken,
  ): Promise<vscode.CompletionItem> {
    return item;
  }
}
